# Meesee
[![Build Status](https://travis-ci.org/Attumm/meesee.svg?branch=master)](https://travis-ci.org/Attumm/meesee)

Task queue, Long lived workers process parallelization, with Redis as backend.

## Getting Started


### Prerequisites

#### Redis

For Debian, Ubuntu
```
sudo apt-get install redis-server
```
For Centos, Red Hat
```
sudo yum install redis
```

### Installing

Create a virtualenv for your project.
Install meesee:

```
$ . /path/to/virtualenv/bin/activate
$  pip install meesee
```

## Authors

* **Melvin Bijman** 
* **Mark Moes**

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

